"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const randomName = require("@scaleway/random-name");
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalOS = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'OS' failed as data isn't a dictionary.`
    );
  }
  return {
    compatibleServerTypes: data.compatible_server_types,
    family: data.family,
    id: data.id,
    imageUrl: data.image_url,
    isBeta: data.is_beta,
    label: data.label,
    name: data.name,
    version: data.version,
    xcodeVersion: data.xcode_version
  };
};
const unmarshalServerTypeCPU = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ServerTypeCPU' failed as data isn't a dictionary.`
    );
  }
  return {
    coreCount: data.core_count,
    frequency: data.frequency,
    name: data.name
  };
};
const unmarshalServerTypeDisk = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ServerTypeDisk' failed as data isn't a dictionary.`
    );
  }
  return {
    capacity: data.capacity,
    type: data.type
  };
};
const unmarshalServerTypeGPU = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ServerTypeGPU' failed as data isn't a dictionary.`
    );
  }
  return {
    count: data.count
  };
};
const unmarshalServerTypeMemory = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ServerTypeMemory' failed as data isn't a dictionary.`
    );
  }
  return {
    capacity: data.capacity,
    type: data.type
  };
};
const unmarshalServerTypeNetwork = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ServerTypeNetwork' failed as data isn't a dictionary.`
    );
  }
  return {
    publicBandwidthBps: data.public_bandwidth_bps
  };
};
const unmarshalServerType = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ServerType' failed as data isn't a dictionary.`
    );
  }
  return {
    cpu: data.cpu ? unmarshalServerTypeCPU(data.cpu) : void 0,
    defaultOs: data.default_os ? unmarshalOS(data.default_os) : void 0,
    disk: data.disk ? unmarshalServerTypeDisk(data.disk) : void 0,
    gpu: data.gpu ? unmarshalServerTypeGPU(data.gpu) : void 0,
    memory: data.memory ? unmarshalServerTypeMemory(data.memory) : void 0,
    minimumLeaseDuration: data.minimum_lease_duration,
    name: data.name,
    network: data.network ? unmarshalServerTypeNetwork(data.network) : void 0,
    stock: data.stock
  };
};
const unmarshalServer = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Server' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    deletableAt: marshalling.unmarshalDate(data.deletable_at),
    deletionScheduled: data.deletion_scheduled,
    delivered: data.delivered,
    id: data.id,
    ip: data.ip,
    name: data.name,
    organizationId: data.organization_id,
    os: data.os ? unmarshalOS(data.os) : void 0,
    projectId: data.project_id,
    sshUsername: data.ssh_username,
    status: data.status,
    sudoPassword: data.sudo_password,
    type: data.type,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    vncPort: data.vnc_port,
    vncUrl: data.vnc_url,
    zone: data.zone
  };
};
const unmarshalConnectivityDiagnosticServerHealth = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ConnectivityDiagnosticServerHealth' failed as data isn't a dictionary.`
    );
  }
  return {
    isAgentAlive: data.is_agent_alive,
    isMdmAlive: data.is_mdm_alive,
    isServerAlive: data.is_server_alive,
    isSshPortUp: data.is_ssh_port_up,
    isVncPortUp: data.is_vnc_port_up,
    lastCheckinDate: marshalling.unmarshalDate(data.last_checkin_date)
  };
};
const unmarshalConnectivityDiagnostic = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ConnectivityDiagnostic' failed as data isn't a dictionary.`
    );
  }
  return {
    errorMessage: data.error_message,
    healthDetails: data.health_details ? unmarshalConnectivityDiagnosticServerHealth(data.health_details) : void 0,
    id: data.id,
    isHealthy: data.is_healthy,
    status: data.status,
    supportedActions: data.supported_actions
  };
};
const unmarshalListOSResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListOSResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    os: marshalling.unmarshalArrayOfObject(data.os, unmarshalOS),
    totalCount: data.total_count
  };
};
const unmarshalListServerTypesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListServerTypesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    serverTypes: marshalling.unmarshalArrayOfObject(data.server_types, unmarshalServerType)
  };
};
const unmarshalListServersResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListServersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    servers: marshalling.unmarshalArrayOfObject(data.servers, unmarshalServer),
    totalCount: data.total_count
  };
};
const unmarshalStartConnectivityDiagnosticResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'StartConnectivityDiagnosticResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    diagnosticId: data.diagnostic_id
  };
};
const marshalCreateServerRequest = (request, defaults) => ({
  name: request.name || randomName("as"),
  os_id: request.osId,
  project_id: request.projectId ?? defaults.defaultProjectId,
  type: request.type
});
const marshalReinstallServerRequest = (request, defaults) => ({
  os_id: request.osId
});
const marshalStartConnectivityDiagnosticRequest = (request, defaults) => ({
  server_id: request.serverId
});
const marshalUpdateServerRequest = (request, defaults) => ({
  name: request.name,
  schedule_deletion: request.scheduleDeletion
});
exports.marshalCreateServerRequest = marshalCreateServerRequest;
exports.marshalReinstallServerRequest = marshalReinstallServerRequest;
exports.marshalStartConnectivityDiagnosticRequest = marshalStartConnectivityDiagnosticRequest;
exports.marshalUpdateServerRequest = marshalUpdateServerRequest;
exports.unmarshalConnectivityDiagnostic = unmarshalConnectivityDiagnostic;
exports.unmarshalListOSResponse = unmarshalListOSResponse;
exports.unmarshalListServerTypesResponse = unmarshalListServerTypesResponse;
exports.unmarshalListServersResponse = unmarshalListServersResponse;
exports.unmarshalOS = unmarshalOS;
exports.unmarshalServer = unmarshalServer;
exports.unmarshalServerType = unmarshalServerType;
exports.unmarshalStartConnectivityDiagnosticResponse = unmarshalStartConnectivityDiagnosticResponse;
