"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalKubernetesACLInfo = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'KubernetesACLInfo' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalKubernetesClusterInfo = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'KubernetesClusterInfo' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalKubernetesNodeInfo = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'KubernetesNodeInfo' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    name: data.name
  };
};
const unmarshalKubernetesPoolInfo = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'KubernetesPoolInfo' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    name: data.name
  };
};
const unmarshalSecretManagerSecretInfo = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'SecretManagerSecretInfo' failed as data isn't a dictionary.`
    );
  }
  return {
    path: data.path
  };
};
const unmarshalSecretManagerSecretVersionInfo = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'SecretManagerSecretVersionInfo' failed as data isn't a dictionary.`
    );
  }
  return {
    revision: data.revision
  };
};
const unmarshalEventPrincipal = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EventPrincipal' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id
  };
};
const unmarshalResource = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Resource' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    deletedAt: marshalling.unmarshalDate(data.deleted_at),
    id: data.id,
    kubeAclInfo: data.kube_acl_info ? unmarshalKubernetesACLInfo(data.kube_acl_info) : void 0,
    kubeClusterInfo: data.kube_cluster_info ? unmarshalKubernetesClusterInfo(data.kube_cluster_info) : void 0,
    kubeNodeInfo: data.kube_node_info ? unmarshalKubernetesNodeInfo(data.kube_node_info) : void 0,
    kubePoolInfo: data.kube_pool_info ? unmarshalKubernetesPoolInfo(data.kube_pool_info) : void 0,
    name: data.name,
    secmSecretInfo: data.secm_secret_info ? unmarshalSecretManagerSecretInfo(data.secm_secret_info) : void 0,
    secmSecretVersionInfo: data.secm_secret_version_info ? unmarshalSecretManagerSecretVersionInfo(data.secm_secret_version_info) : void 0,
    type: data.type,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalEvent = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Event' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    locality: data.locality,
    methodName: data.method_name,
    organizationId: data.organization_id,
    principal: data.principal ? unmarshalEventPrincipal(data.principal) : void 0,
    productName: data.product_name,
    projectId: data.project_id,
    recordedAt: marshalling.unmarshalDate(data.recorded_at),
    requestBody: data.request_body,
    requestId: data.request_id,
    resource: data.resource ? unmarshalResource(data.resource) : void 0,
    serviceName: data.service_name,
    sourceIp: data.source_ip,
    statusCode: data.status_code,
    userAgent: data.user_agent
  };
};
const unmarshalListEventsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListEventsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    events: marshalling.unmarshalArrayOfObject(data.events, unmarshalEvent),
    nextPageToken: data.next_page_token
  };
};
const unmarshalProduct = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Product' failed as data isn't a dictionary.`
    );
  }
  return {
    name: data.name,
    title: data.title
  };
};
const unmarshalListProductsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListProductsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    products: marshalling.unmarshalArrayOfObject(data.products, unmarshalProduct),
    totalCount: data.total_count
  };
};
exports.unmarshalEvent = unmarshalEvent;
exports.unmarshalListEventsResponse = unmarshalListEventsResponse;
exports.unmarshalListProductsResponse = unmarshalListProductsResponse;
exports.unmarshalResource = unmarshalResource;
